package com.game.business.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.game.business.domain.AppGame;
import com.game.business.domain.AppGameBetting;
import com.game.business.domain.AppGameLottery;
import com.game.business.dto.AppGameBettingDetailsCountDTO;
import com.game.business.dto.AppGameLotteryDTO;
import com.game.business.service.IAppGameLotteryService;
import com.game.business.service.IAppGameService;
import com.game.common.annotation.Anonymous;
import com.game.common.core.controller.BaseController;
import com.game.common.core.domain.HttpRetPageArr;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@RestController
@RequestMapping("/business/lottery")
@Api(value = "AppGameLotteryController", description = "游戏开奖接口", tags = {"游戏开奖记录"})
public class AppGameLotteryController extends BaseController{

    @Autowired
    private IAppGameLotteryService appGameLotteryService;

    @Autowired
    private IAppGameService appGameService;

    @Anonymous
    @PostMapping(value = "/list")
    @ApiOperation(value = "游戏开奖记录", notes = "游戏开奖记录")
    public HttpRetPageArr<AppGameLottery> getListByGameId(@RequestParam(name = "gameId") Long gameId, @RequestParam(name= "gameDate", required = false) String gameDate
            , @RequestParam(name= "strDate", required = false) String strDate)
    {
        startPage();

        LambdaQueryWrapper<AppGameLottery> queryLotteryWrapper = Wrappers.lambdaQuery();;
        queryLotteryWrapper.eq(AppGameLottery::getGameId, gameId);
        if(StringUtils.isNoneBlank(gameDate)) {
            queryLotteryWrapper.like(AppGameLottery::getGameDate, gameDate);
        }
        if(StringUtils.isNoneBlank(strDate)){
            queryLotteryWrapper.between(AppGameLottery::getGameRecordDate, strDate + " 00:00:00", strDate + " 23:59:59");
        }
        queryLotteryWrapper.orderByDesc(AppGameLottery::getGameRecordDate);
        List<AppGameLottery> list = appGameLotteryService.list(queryLotteryWrapper);

//        List<AppGameLotteryDTO> resultList = new ArrayList<>();
//
//        if(list != null && !list.isEmpty()){
//            List<AppGame> gameList = appGameService.selectAppGameList(new AppGame());
//            Map<Long, List<AppGame>> idGameMap = gameList.stream().collect(Collectors.groupingBy(AppGame::getId));
//
//            for (AppGameLottery appGameLottery : list) {
//                AppGameLotteryDTO dto = new AppGameLotteryDTO();
//                if(idGameMap.containsKey(appGameLottery.getGameId())){
//                    AppGame appGame = idGameMap.get(appGameLottery.getGameId()).get(0);
//                    dto.setGamePath(appGame.getGamePath());
//                    dto.setGameName(appGame.getName());
//                    dto.setLogoUrl(appGame.getLogoUrl());
//                }
//                dto.setGameId(appGameLottery.getGameId());
//                dto.setGameDate(appGameLottery.getGameDate());
//                dto.setClassId(appGameLottery.getClassId());
//                dto.setGameLotterySucc(appGameLottery.getGameLotterySucc());
//                dto.setGameRecordDate(appGameLottery.getGameRecordDate());
//                resultList.add(dto);
//            }
//        }

        return HttpRetPageArr.success("查询成功",getDataTable(list));
    }
}
